import type { EventName, ReactWebComponent } from '@lit/react';
type EventNames = Record<string, EventName | string>;
/**
 * these types are defined by a Stencil hydrate app so we have to copy the minimal types here
 */
interface RenderToStringOptions {
    fullDocument?: boolean;
    serializeShadowRoot?: boolean;
    prettyHtml?: boolean;
}
export type RenderToString = (html: string, options: RenderToStringOptions) => Promise<{
    html: string | null;
}>;
interface CreateComponentForServerSideRenderingOptions {
    tagName: string;
    properties: Record<string, string>;
    renderToString: RenderToString;
}
/**
 * transform a React component into a Stencil component for server side rendering
 *
 * Note: this code should only be loaded on the server side, as it uses heavy Node.js dependencies
 * that when loaded on the client side would increase the bundle size.
 */
export declare const createComponentForServerSideRendering: <I extends HTMLElement, E extends EventNames = {}>(options: CreateComponentForServerSideRenderingOptions) => ReactWebComponent<I, E>;
export {};
